@@ -14,6 +14,8 @@ Options:
 -l, --list      List available block types and their names (from
                 <http://www.minecraftwiki.net/wiki/Data_values>).
 -n, --nether    Graph The Nether instead of the ordinary world.
+--log           Render logarithmic output.
+-s, --save      Save the result to file instead of showing an interactive GUI.
 
 Description:
 
@@ -42,7 +44,7 @@ __maintainer__ = 'Victor Engmark'
 __email__ = 'victor.engmark@gmail.com'
 __license__ = 'GPL v3 or newer'
 __url__ = 'https://github.com/l0b0/mian/wiki'
-__version__ = '0.9.1'
+__version__ = '0.9.2'
 
 from binascii import unhexlify
 from getopt import getopt, GetoptError
@@ -164,7 +166,7 @@ def print_block_types():
             sys.stdout.write(', '.join(block_names) + '\n')
 
 
-def plot(counts, block_type_hexes, title, interactive):
+def plot(counts, block_type_hexes, title, log, interactive):
     """
     Actual plotting of data.
 
@@ -174,11 +176,19 @@ def plot(counts, block_type_hexes, title, interactive):
     fig = plt.figure()
     fig.canvas.set_window_title(title)
 
-    for index, block_counts in enumerate(counts):
-        plt.plot(
-            block_counts,
-            label=BLOCK_TYPES[block_type_hexes[index]][0],
-            linewidth=1)
+    if log:
+        for index, block_counts in enumerate(counts):
+            plt.semilogy(
+                block_counts,
+                label=BLOCK_TYPES[block_type_hexes[index]][0],
+                linewidth=1,
+                nonposy='clip')
+    else:
+        for index, block_counts in enumerate(counts):
+            plt.plot(
+                block_counts,
+                label=BLOCK_TYPES[block_type_hexes[index]][0],
+                linewidth=1)
 
     plt.legend()
     plt.xlabel(LABEL_X)
@@ -190,7 +200,7 @@ def plot(counts, block_type_hexes, title, interactive):
         plt.savefig(title + '.png')
 
 
-def mian(world_dir, block_type_hexes, nether, interactive):
+def mian(world_dir, block_type_hexes, nether, log, interactive):
     """
     Runs through the MCR files and gets the layer counts for the plot.
 
@@ -245,7 +255,7 @@ def mian(world_dir, block_type_hexes, nether, interactive):
 
     print "Done!"
 
-    plot(total_counts, block_type_hexes, title, interactive)
+    plot(total_counts, block_type_hexes, title, log, interactive)
 
 
 def count_blocks(region_blocks, block_type_hexes):
@@ -346,13 +356,14 @@ def main(argv=None):
     block_type_names = DEFAULT_BLOCK_TYPES
     nether = False
     interactive = True
+    log = False
 
     try:
         try:
             opts, args = getopt(
                 argv[1:],
                 'b:lnhs',
-                ['blocks=', 'list', 'nether', 'save', 'help'])
+                ['blocks=', 'list', 'nether', 'log', 'save', 'help'])
         except GetoptError, err:
             raise Usage(str(err))
 
@@ -361,6 +372,8 @@ def main(argv=None):
                 block_type_names = value.split(',')
             elif option in ('-n', '--nether'):
                 nether = True
+            elif option in ('--log'):
+                log = True
             elif option in ('-s', '--save'):
                 interactive = False
             elif option in ('-l', '--list'):
@@ -388,7 +401,7 @@ def main(argv=None):
                 if found_hex not in block_type_hexes:  # Avoid duplicates
                     block_type_hexes.append(found_hex)
 
-        mian(world_dir, block_type_hexes, nether, interactive)
+        mian(world_dir, block_type_hexes, nether, log, interactive)
 
     except Usage, err:
         sys.stderr.write(err.msg + '\n')
